AssetType class

Implementers

Constructors

AssetType({required String rootPath, required String path, required Set<String> flavors, required Set<String> transformers, bool isThemed = false})

Properties

baseName String
latefinal
children → SortedList<AssetType>
latefinal
extension String
latefinal
flavors Set<String>
final
fullPath String
Returns the full absolute path for reading the asset file.
latefinal
hashCode int
The hash code for this object.
no setterinherited
isDefaultAssetsDirectory bool
latefinal
isIgnoreFile bool
latefinal
isThemed bool
final
isUnKnownMime bool
latefinal
mime String?
latefinal
name String
Returns a name for this asset.
latefinal
path String
final
pathWithoutTheme String
no setter
posixStylePath String
latefinal
rootPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transformers Set<String>
final

Methods

addChild(AssetType type) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pathThemed1() String
pathThemed2() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited