UniqueAssetType class

Represents a AssetType with modifiers on it to mutate the name to ensure it is unique in a larger list and a valid dart identifer.

See AssetTypeIterable.mapToUniqueAssetType for the algorithm.

Inheritance

Constructors

UniqueAssetType({required AssetType assetType, String style(String) = camelCase, bool basenameOnly = false, bool needExtension = false, String suffix = ''})

Properties

baseName String
latefinalinherited
basenameOnly bool
Include just the basename of the asset in the name, e.g. 'images/image.png' -> 'image'.
final
children → SortedList<AssetType>
latefinalinherited
extension String
latefinalinherited
flavors Set<String>
finalinherited
fullPath String
Returns the full absolute path for reading the asset file.
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
isDefaultAssetsDirectory bool
latefinalinherited
isIgnoreFile bool
latefinalinherited
isThemed bool
finalinherited
isUnKnownMime bool
latefinalinherited
mime String?
latefinalinherited
name String
Returns a identifier name, which is ideally unique and valid.
no setteroverride
needExtension bool
Include the extension in the name, e.g. 'image.png' -> 'imagePng'.
getter/setter pair
path String
finalinherited
pathWithoutTheme String
no setterinherited
posixStylePath String
latefinalinherited
rootPath String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style String Function(String)
Convert the asset name to a correctly styled name, e.g camelCase or snakeCase.
final
suffix String
Optional suffix to append to the name to make it unique. Typically just one or more '_' characters.
getter/setter pair
transformers Set<String>
finalinherited

Methods

addChild(AssetType type) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pathThemed1() String
inherited
pathThemed2() String
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited